TlvOwned

Struct TlvOwned 

pub struct TlvOwned { /* private fields */ }
Available on crate feature alloc only.
Owned variant of Tlv which is consequently Cloneable and does not have a lifetime associated to a data slice.

Implementations

Source

impl TlvOwned

pub fn new(tlv_type: TlvType, data: &[u8]) -> Self

Generic constructor.

pub fn new_with_custom_type(tlv_type: u8, data: &[u8]) -> Self

Generic constructor with a custom TLV type.

pub fn new_empty(tlv_type: TlvType) -> Self

Creates a TLV with an empty value field.

pub fn write_to_bytes( &self, buf: &mut [u8], ) -> Result<usize, ByteConversionError>

Write to a byte slice.

pub fn as_tlv(&self) -> Tlv<'_>

Convert to Tlv