PusTcReader

Struct PusTcReader 

pub struct PusTcReader<'raw_data> { /* private fields */ }
This class can be used to read a PUS TC telecommand from raw memory.

This class also derives the serde::Serialize and serde::Deserialize trait if the serde feature is used, which allows to send around TC packets in a raw byte format using a serde provider like postcard.

There is no spare bytes support yet.

Lifetimes

  • 'raw_data - Lifetime of the provided raw slice.

Implementations

Source

impl<'raw_data> PusTcReader<'raw_data>

pub fn new(slice: &'raw_data [u8]) -> Result<Self, PusError>

Create a PusTcReader instance from a raw slice. The given packet should have a a CRC-16-CCITT checksum which is also verified.

pub fn new_checksum_no_table(slice: &'raw_data [u8]) -> Result<Self, PusError>

Similar to PusTcReader::new, but uses a table-less CRC16 algorithm which can reduce binary size and memory usage.

pub fn new_no_checksum(slice: &'raw_data [u8]) -> Result<Self, PusError>

Read a PUS TC from a raw slice where no checksum is expected.

pub fn new_no_checksum_verification( slice: &'raw_data [u8], has_checksum: bool, ) -> Result<Self, PusError>

Create a new Self instance without verifying the checksum, even if the packet has one.

pub fn app_data(&self) -> &[u8]

Application data slice.

pub fn raw_data(&self) -> &[u8]

Full raw data slice.

pub fn len_packed(&self) -> usize

Length of the packed data.

pub fn sp_header(&self) -> &SpHeader

Space packet header.

pub fn crc16(&self) -> Option<u16>

CRC16 checksum if present.