#[repr(u8)]pub enum SourceOrDestField {
Source = 0,
Dest = 1,
}Expand description
Identifies the association of the data contained in the transfer frame.
Variants
Source = 0
SCID refers to the source of the transfer frame.
Dest = 1
SCID refers to the destination of the transfer frame.
Implementations