pub enum CdsError {
InvalidCcsdsDays(i64),
InvalidCtorForDaysOfLenInPreamble(LengthOfDaySegment),
DateBeforeCcsdsEpoch(DateBeforeCcsdsEpochError),
}Expand description
CDS timestamp error.
Variants
InvalidCcsdsDays(i64)
CCSDS days value exceeds maximum allowed size or is negative
InvalidCtorForDaysOfLenInPreamble(LengthOfDaySegment)
There are distinct constructors depending on the days field width detected in the preamble field. This error will be returned if there is a missmatch.
DateBeforeCcsdsEpoch(DateBeforeCcsdsEpochError)
Date is before the CCSDS epoch (1958-01-01T00:00:00+00:00)